sphinxcontrib_applehelp: Sphinx extension which outputs Apple help book
=======================================================================

Description
-----------

Sphinx extension which outputs Apple help book

License
-------

BSD
